@@ -7,14 +7,23 @@
 makedata <- function(phi, stimuli, R.t=3, R.b=3, TT=10,
 		mu.bg=0, sd.bg=0.1,
 		mu.signal.a=2, sd.signal.a=0.5,
-		mu.signal.i=-2, sd.signal.i=0.5) {
+		mu.signal.i=-2, sd.signal.i=0.5, allow.stim.off=FALSE) {	
 	dat <- gam <- NULL
+	if(length(R.t)!=length(stimuli)) {
+		R.t <- rep(R.t, length(stimuli))
+	}
+	if(length(R.b)!=length(stimuli)) {
+		R.b <- rep(R.b, length(stimuli))
+	}
+	if(length(TT)!=length(stimuli)) {
+		TT <- rep(TT, length(stimuli))
+	}
 	for(i in 1:length(stimuli)) {
 		stimulus <- stimuli[[i]]
 		datx <- simulatedata(phi, mu.bg=mu.bg, sd.bg=sd.bg,
 				mu.signal.a=mu.signal.a, sd.signal.a=sd.signal.a,
 				mu.signal.i=mu.signal.i, sd.signal.i=sd.signal.i,
-				stimulus=stimulus,TT=TT,R.t=R.t,R.b=R.b,plot=F,stimuli=stimuli)
+				stimulus=stimulus,TT=TT[i],R.t=R.t[i],R.b=R.b[i],plot=F,stimuli=stimuli,allow.stim.off=allow.stim.off)
 		gamt <- datx$gammax
 		datt <- datx$datx
 		for(j in unique(unlist(stimuli))) {
