@@ -11,8 +11,11 @@ netga <- function(dat, stimuli, P=NULL, maxiterations=1000, p=100,
 		scale_lik=FALSE, allow.stim.off=TRUE,debug=0,retobj=NULL) {
   dat[is.na(dat)] <- 0
   V <- rownames(dat)
-  tps <- unique(sapply(colnames(dat), function(x) strsplit(x,"_")[[1]][2]))
-  reps <- table(sub("_[0-9].*$","",colnames(dat))) / length(tps)
+  ordstim <- sapply(stimuli, function(x) paste(names(x),collapse="&"))
+  tmp <- tapply(colnames(dat), gsub("_.*$","",colnames(dat)), get_reps_tps)
+  tmp <- tmp[ordstim]	
+  tps <- lapply(tmp, function(x) x$tps)
+  reps <- sapply(tmp, function(x) as.numeric(x$reps))
   phireference <- matrix(0,nrow=length(V), ncol=length(V), dimnames=list(V,V))
 
   #####################################################################
@@ -28,9 +31,12 @@ netga <- function(dat, stimuli, P=NULL, maxiterations=1000, p=100,
 	  	X[[2]] <- phireference
 	  }
 	  if(multicores) {
-		P <- mclapply(X, getfirstphi, dat=dat,stimuli=stimuli,V=V,tps=tps,reps=reps,hmmiterations=hmmiterations,lambda=lambda,B=B,Z=Z,fanin=fanin,gam=gam,it=it,K=K,priortype=priortype,scale_lik=scale_lik, mc.preschedule=FALSE,mc.cores=cores, allow.stim.off=allow.stim.off)		
+		P <- mclapply(X, getfirstphi, dat=dat,stimuli=stimuli,V=V,tps=tps,reps=reps,hmmiterations=hmmiterations,lambda=lambda,B=B,Z=Z,
+				                      fanin=fanin,gam=gam,it=it,K=K,priortype=priortype,scale_lik=scale_lik, allow.stim.off=allow.stim.off,
+									  mc.preschedule=FALSE,mc.cores=cores)		
 	  } else {
-		P <- lapply(X, getfirstphi, dat=dat,stimuli=stimuli,V=V,tps=tps,reps=reps,hmmiterations=hmmiterations,lambda=lambda,B=B,Z=Z,fanin=fanin,gam=gam,it=it,K=K,priortype=priortype,scale_lik=scale_lik, allow.stim.off=allow.stim.off)
+		P <- lapply(X, getfirstphi, dat=dat,stimuli=stimuli,V=V,tps=tps,reps=reps,hmmiterations=hmmiterations,lambda=lambda,B=B,Z=Z,
+				                    fanin=fanin,gam=gam,it=it,K=K,priortype=priortype,scale_lik=scale_lik, allow.stim.off=allow.stim.off)
 	  }
   }
   ## check if all individuals are set correctly
